@@ -1,10 +1,13 @@
 from __future__ import annotations
 
 import functools
+import hashlib
 from typing import Any, MutableMapping
 
 __all__ = ("decorators", "rgetattr", "rsetattr")
 
+from pylavcogs_shared.types import GenericT
+
 
 def rsetattr(obj: object, attr: str, val: Any) -> None:
     pre, _, post = attr.rpartition(".")
@@ -28,3 +31,16 @@ def recursive_merge(d1: dict, d2: dict) -> dict:
         if k in d2 and all(isinstance(e, MutableMapping) for e in (v, d2[k])):
             d2[k] = recursive_merge(v, d2[k])
     return d1 | d2
+
+
+class Mutator:
+    def __init__(self, obj: object):  # sourcery skip: remove-unnecessary-cast
+        self.obj = obj
+        self.name = obj.name if hasattr(obj, "name") else str(obj.__class__.__name__)
+        if hasattr(obj, "id"):
+            self.id = str(obj.id)
+        else:
+            i = hashlib.md5()
+            i.update(self.name.encode())
+            i.update(str(id(obj)).encode())
+            self.id = str(int(i.hexdigest(), 16))[:16]
